@@ -17,6 +17,7 @@ import { KubeHelper } from '../api/kube'
 import { OpenShiftHelper } from '../api/openshift'
 import { VersionHelper } from '../api/version'
 import { CHE_OPERATOR_SELECTOR, DOC_LINK, DOC_LINK_RELEASE_NOTES, OUTPUT_SEPARATOR } from '../constants'
+import { base64Decode } from '../util'
 
 import { KubeTasks } from './kube'
 
@@ -414,72 +415,45 @@ export class CheTasks {
       {
         title: 'Delete configmaps for CodeReady Workspaces server and operator',
         task: async (_ctx: any, task: any) => {
-          if (await this.kube.getConfigMap('che', flags.chenamespace)) {
-            await this.kube.deleteConfigMap('che', flags.chenamespace)
-          }
-          if (await this.kube.getConfigMap('codeready-operator', flags.chenamespace)) {
-            await this.kube.deleteConfigMap('codeready-operator', flags.chenamespace)
-          }
+          await this.kube.deleteConfigMap('che', flags.chenamespace)
+          await this.kube.deleteConfigMap('codeready-operator', flags.chenamespace)
           task.title = await `${task.title}...OK`
         }
       },
       {
         title: 'Delete rolebindings che, che-workspace-exec and che-workspace-view',
         task: async (_ctx: any, task: any) => {
-          if (await this.kube.roleBindingExist('che', flags.chenamespace)) {
-            await this.kube.deleteRoleBinding('che', flags.chenamespace)
-          }
-          if (await this.kube.roleBindingExist('codeready-operator', flags.chenamespace)) {
-            await this.kube.deleteRoleBinding('codeready-operator', flags.chenamespace)
-          }
-          if (await this.kube.roleBindingExist('che-workspace-exec', flags.chenamespace)) {
-            await this.kube.deleteRoleBinding('che-workspace-exec', flags.chenamespace)
-          }
-          if (await this.kube.roleBindingExist('che-workspace-view', flags.chenamespace)) {
-            await this.kube.deleteRoleBinding('che-workspace-view', flags.chenamespace)
-          }
+          await this.kube.deleteRoleBinding('che', flags.chenamespace)
+          await this.kube.deleteRoleBinding('codeready-operator', flags.chenamespace)
+          await this.kube.deleteRoleBinding('che-workspace-exec', flags.chenamespace)
+          await this.kube.deleteRoleBinding('che-workspace-view', flags.chenamespace)
           task.title = await `${task.title}...OK`
         }
       },
       {
         title: 'Delete service accounts che, che-workspace',
         task: async (_ctx: any, task: any) => {
-          if (await this.kube.serviceAccountExist('che', flags.chenamespace)) {
-            await this.kube.deleteServiceAccount('che', flags.chenamespace)
-          }
-          if (await this.kube.roleBindingExist('che-workspace', flags.chenamespace)) {
-            await this.kube.deleteServiceAccount('che-workspace', flags.chenamespace)
-          }
+          await this.kube.deleteServiceAccount('che', flags.chenamespace)
+          await this.kube.deleteServiceAccount('che-workspace', flags.chenamespace)
           task.title = await `${task.title}...OK`
         }
       },
       {
         title: 'Delete PVCs',
         task: async (_ctx: any, task: any) => {
-          if (await this.kube.persistentVolumeClaimExist('postgres-data', flags.chenamespace)) {
-            await this.kube.deletePersistentVolumeClaim('postgres-data', flags.chenamespace)
-          }
-          if (await this.kube.persistentVolumeClaimExist('che-data-volume', flags.chenamespace)) {
-            await this.kube.deletePersistentVolumeClaim('che-data-volume', flags.chenamespace)
-          }
-
-          if (await this.kube.persistentVolumeClaimExist('keycloak-data', flags.chenamespace)) {
-            await this.kube.deletePersistentVolumeClaim('keycloak-data', flags.chenamespace)
-          }
-          if (await this.kube.persistentVolumeClaimExist('keycloak-log', flags.chenamespace)) {
-            await this.kube.deletePersistentVolumeClaim('keycloak-log', flags.chenamespace)
-          }
-
+          await this.kube.deletePersistentVolumeClaim('postgres-data', flags.chenamespace)
+          await this.kube.deletePersistentVolumeClaim('che-data-volume', flags.chenamespace)
+          await this.kube.deletePersistentVolumeClaim('keycloak-data', flags.chenamespace)
+          await this.kube.deletePersistentVolumeClaim('keycloak-log', flags.chenamespace)
           task.title = `${task.title}...OK`
         }
       },
       {
         title: `Delete consoleLink ${this.cheConsoleLinkName}`,
         task: async (_ctx: any, task: any) => {
-          const consoleLinkExists = await this.kube.consoleLinkExists(this.cheConsoleLinkName)
           const checlusters = await this.kube.getAllCheClusters()
           // Delete the consoleLink only in case if there no more checluster installed
-          if (checlusters.length === 0 && consoleLinkExists) {
+          if (checlusters.length === 0) {
             await this.kube.deleteConsoleLink(this.cheConsoleLinkName)
           }
           task.title = `${task.title}...OK`
@@ -675,7 +649,20 @@ export class CheTasks {
 
           const cheUrl = await this.che.cheURL(flags.chenamespace)
           messages.push(`Users Dashboard           : ${cheUrl}`)
-          messages.push('Admin user login          : "admin:admin". NOTE: must change after first login.')
+
+          const cr = await this.kube.getCheCluster(flags.chenamespace)
+          if (ctx.isOpenShift && cr && cr.spec && cr.spec.auth && cr.spec.auth.openShiftoAuth) {
+            if (cr.status && cr.status.openShiftOAuthUserCredentialsSecret) {
+              const credentialsSecret = await this.kube.getSecret(cr.status.openShiftOAuthUserCredentialsSecret, flags.chenamespace)
+              if (credentialsSecret) {
+                const user = base64Decode(credentialsSecret.data!.user)
+                const password = base64Decode(credentialsSecret.data!.password)
+                messages.push(`HTPasswd user credentials : "${user}:${password}".`)
+              }
+            }
+          } else {
+            messages.push('Admin user login          : "admin:admin". NOTE: must change after first login.')
+          }
           messages.push(OUTPUT_SEPARATOR)
 
           const cheConfigMap = await this.kube.getConfigMap('che', flags.chenamespace)
